@@ -20,10 +20,12 @@ var _ fmt.Stringer = Type(0)
 func TestAdd(t *testing.T) {
 	var g errgroup.Group
 	artifacts := New()
+	wd, _ := os.Getwd()
 	for _, a := range []*Artifact{
 		{
 			Name: "foo",
 			Type: UploadableArchive,
+			Path: filepath.Join(wd, "/foo/bar.tgz"),
 		},
 		{
 			Name: "bar",
@@ -46,6 +48,8 @@ func TestAdd(t *testing.T) {
 	}
 	require.NoError(t, g.Wait())
 	require.Len(t, artifacts.List(), 4)
+	archives := artifacts.Filter(ByType(UploadableArchive)).List()
+	require.Len(t, archives, 1)
 }
 
 func TestFilter(t *testing.T) {
@@ -922,3 +926,11 @@ func TestArtifactStringer(t *testing.T) {
 		Name: "foobar",
 	}.String())
 }
+
+func TestArtifactTypeStringer(t *testing.T) {
+	for i := 1; i <= 29; i++ {
+		t.Run(fmt.Sprintf("type-%d-%s", i, Type(i).String()), func(t *testing.T) {
+			require.NotEqual(t, "unknown", Type(i).String())
+		})
+	}
+}
