@@ -35,20 +35,35 @@ func urlFor(ctx *context.Context, conf config.Blob) (string, error) {
 		return "", err
 	}
 
-	bucketURL := fmt.Sprintf("%s://%s", conf.Provider, bucket)
+	provider, err := tmpl.New(ctx).Apply(conf.Provider)
+	if err != nil {
+		return "", err
+	}
 
-	if conf.Provider != "s3" {
+	bucketURL := fmt.Sprintf("%s://%s", provider, bucket)
+	if provider != "s3" {
 		return bucketURL, nil
 	}
 
 	query := url.Values{}
-	if conf.Endpoint != "" {
-		query.Add("endpoint", conf.Endpoint)
+
+	endpoint, err := tmpl.New(ctx).Apply(conf.Endpoint)
+	if err != nil {
+		return "", err
+	}
+	if endpoint != "" {
+		query.Add("endpoint", endpoint)
 		query.Add("s3ForcePathStyle", "true")
 	}
-	if conf.Region != "" {
-		query.Add("region", conf.Region)
+
+	region, err := tmpl.New(ctx).Apply(conf.Region)
+	if err != nil {
+		return "", err
 	}
+	if region != "" {
+		query.Add("region", region)
+	}
+
 	if conf.DisableSSL {
 		query.Add("disableSSL", "true")
 	}
@@ -206,9 +221,7 @@ func (u *productionUploader) Close() error {
 }
 
 func (u *productionUploader) Open(ctx *context.Context, bucket string) error {
-	log.WithFields(log.Fields{
-		"bucket": bucket,
-	}).Debug("uploading")
+	log.WithField("bucket", bucket).Debug("uploading")
 
 	conn, err := blob.OpenBucket(ctx, bucket)
 	if err != nil {
