@@ -17,6 +17,10 @@ import (
 	"github.com/stretchr/testify/require"
 )
 
+func TestContinueOnError(t *testing.T) {
+	require.True(t, Pipe{}.ContinueOnError())
+}
+
 func TestDescription(t *testing.T) {
 	require.NotEmpty(t, Pipe{}.String())
 }
@@ -165,8 +169,8 @@ func TestFullPipe(t *testing.T) {
 		"default": {
 			prepare: func(ctx *context.Context) {
 				ctx.TokenType = context.TokenTypeGitHub
-				ctx.Config.Brews[0].Tap.Owner = "test"
-				ctx.Config.Brews[0].Tap.Name = "test"
+				ctx.Config.Brews[0].Repository.Owner = "test"
+				ctx.Config.Brews[0].Repository.Name = "test"
 				ctx.Config.Brews[0].Homepage = "https://github.com/goreleaser"
 			},
 		},
@@ -174,7 +178,7 @@ func TestFullPipe(t *testing.T) {
 			prepare: func(ctx *context.Context) {
 				ctx.TokenType = context.TokenTypeGitHub
 				ctx.Config.Brews[0].Homepage = "https://github.com/goreleaser"
-				ctx.Config.Brews[0].Tap = config.RepoRef{
+				ctx.Config.Brews[0].Repository = config.RepoRef{
 					Name:   "test",
 					Branch: "main",
 					Git: config.GitRepoRef{
@@ -188,7 +192,7 @@ func TestFullPipe(t *testing.T) {
 			prepare: func(ctx *context.Context) {
 				ctx.TokenType = context.TokenTypeGitHub
 				ctx.Config.Brews[0].Homepage = "https://github.com/goreleaser"
-				ctx.Config.Brews[0].Tap = config.RepoRef{
+				ctx.Config.Brews[0].Repository = config.RepoRef{
 					Owner:  "test",
 					Name:   "test",
 					Branch: "update-{{.Version}}",
@@ -201,8 +205,8 @@ func TestFullPipe(t *testing.T) {
 		"custom_download_strategy": {
 			prepare: func(ctx *context.Context) {
 				ctx.TokenType = context.TokenTypeGitHub
-				ctx.Config.Brews[0].Tap.Owner = "test"
-				ctx.Config.Brews[0].Tap.Name = "test"
+				ctx.Config.Brews[0].Repository.Owner = "test"
+				ctx.Config.Brews[0].Repository.Name = "test"
 				ctx.Config.Brews[0].Homepage = "https://github.com/goreleaser"
 
 				ctx.Config.Brews[0].DownloadStrategy = "GitHubPrivateRepositoryReleaseDownloadStrategy"
@@ -211,8 +215,8 @@ func TestFullPipe(t *testing.T) {
 		"custom_require": {
 			prepare: func(ctx *context.Context) {
 				ctx.TokenType = context.TokenTypeGitHub
-				ctx.Config.Brews[0].Tap.Owner = "test"
-				ctx.Config.Brews[0].Tap.Name = "test"
+				ctx.Config.Brews[0].Repository.Owner = "test"
+				ctx.Config.Brews[0].Repository.Name = "test"
 				ctx.Config.Brews[0].Homepage = "https://github.com/goreleaser"
 
 				ctx.Config.Brews[0].DownloadStrategy = "CustomDownloadStrategy"
@@ -222,8 +226,8 @@ func TestFullPipe(t *testing.T) {
 		"custom_block": {
 			prepare: func(ctx *context.Context) {
 				ctx.TokenType = context.TokenTypeGitHub
-				ctx.Config.Brews[0].Tap.Owner = "test"
-				ctx.Config.Brews[0].Tap.Name = "test"
+				ctx.Config.Brews[0].Repository.Owner = "test"
+				ctx.Config.Brews[0].Repository.Name = "test"
 				ctx.Config.Brews[0].Homepage = "https://github.com/goreleaser"
 
 				ctx.Config.Brews[0].CustomBlock = `head "https://github.com/caarlos0/test.git"`
@@ -232,55 +236,55 @@ func TestFullPipe(t *testing.T) {
 		"default_gitlab": {
 			prepare: func(ctx *context.Context) {
 				ctx.TokenType = context.TokenTypeGitLab
-				ctx.Config.Brews[0].Tap.Owner = "test"
-				ctx.Config.Brews[0].Tap.Name = "test"
+				ctx.Config.Brews[0].Repository.Owner = "test"
+				ctx.Config.Brews[0].Repository.Name = "test"
 				ctx.Config.Brews[0].Homepage = "https://gitlab.com/goreleaser"
 			},
 		},
 		"invalid_commit_template": {
 			prepare: func(ctx *context.Context) {
-				ctx.Config.Brews[0].Tap.Owner = "test"
-				ctx.Config.Brews[0].Tap.Name = "test"
+				ctx.Config.Brews[0].Repository.Owner = "test"
+				ctx.Config.Brews[0].Repository.Name = "test"
 				ctx.Config.Brews[0].CommitMessageTemplate = "{{ .Asdsa }"
 			},
 			expectedPublishError: `template: tmpl:1: unexpected "}" in operand`,
 		},
-		"valid_tap_templates": {
+		"valid_repository_templates": {
 			prepare: func(ctx *context.Context) {
 				ctx.TokenType = context.TokenTypeGitHub
 				ctx.Env = map[string]string{
 					"FOO": "templated",
 				}
-				ctx.Config.Brews[0].Tap.Owner = "{{.Env.FOO}}"
-				ctx.Config.Brews[0].Tap.Name = "{{.Env.FOO}}"
+				ctx.Config.Brews[0].Repository.Owner = "{{.Env.FOO}}"
+				ctx.Config.Brews[0].Repository.Name = "{{.Env.FOO}}"
 			},
 		},
-		"invalid_tap_name_template": {
+		"invalid_repository_name_template": {
 			prepare: func(ctx *context.Context) {
-				ctx.Config.Brews[0].Tap.Owner = "test"
-				ctx.Config.Brews[0].Tap.Name = "{{ .Asdsa }"
+				ctx.Config.Brews[0].Repository.Owner = "test"
+				ctx.Config.Brews[0].Repository.Name = "{{ .Asdsa }"
 			},
 			expectedRunError: `template: tmpl:1: unexpected "}" in operand`,
 		},
-		"invalid_tap_owner_template": {
+		"invalid_repository_owner_template": {
 			prepare: func(ctx *context.Context) {
-				ctx.Config.Brews[0].Tap.Owner = "{{ .Asdsa }"
-				ctx.Config.Brews[0].Tap.Name = "test"
+				ctx.Config.Brews[0].Repository.Owner = "{{ .Asdsa }"
+				ctx.Config.Brews[0].Repository.Name = "test"
 			},
 			expectedRunError: `template: tmpl:1: unexpected "}" in operand`,
 		},
-		"invalid_tap_skip_upload_template": {
+		"invalid_repository_skip_upload_template": {
 			prepare: func(ctx *context.Context) {
 				ctx.Config.Brews[0].SkipUpload = "{{ .Asdsa }"
-				ctx.Config.Brews[0].Tap.Owner = "test"
-				ctx.Config.Brews[0].Tap.Name = "test"
+				ctx.Config.Brews[0].Repository.Owner = "test"
+				ctx.Config.Brews[0].Repository.Name = "test"
 			},
 			expectedRunError: `template: tmpl:1: unexpected "}" in operand`,
 		},
 		"invalid_install_template": {
 			prepare: func(ctx *context.Context) {
-				ctx.Config.Brews[0].Tap.Owner = "test"
-				ctx.Config.Brews[0].Tap.Name = "test"
+				ctx.Config.Brews[0].Repository.Owner = "test"
+				ctx.Config.Brews[0].Repository.Name = "test"
 				ctx.Config.Brews[0].Install = "{{ .aaaa }"
 			},
 			expectedRunError: `template: tmpl:1: unexpected "}" in operand`,
@@ -373,7 +377,7 @@ func TestFullPipe(t *testing.T) {
 			require.NoError(t, err)
 			require.NoError(t, f.Close())
 			client := client.NewMock()
-			distFile := filepath.Join(folder, name+".rb")
+			distFile := filepath.Join(folder, "homebrew", name+".rb")
 
 			require.NoError(t, Pipe{}.Default(ctx))
 
@@ -391,7 +395,7 @@ func TestFullPipe(t *testing.T) {
 			require.NoError(t, publishAll(ctx, client))
 
 			content := []byte(client.Content)
-			if url := ctx.Config.Brews[0].Tap.Git.URL; url == "" {
+			if url := ctx.Config.Brews[0].Repository.Git.URL; url == "" {
 				require.True(t, client.CreatedFile, "should have created a file")
 			} else {
 				content = testlib.CatFileFromBareRepository(t, url, name+".rb")
@@ -419,7 +423,7 @@ func TestRunPipeNameTemplate(t *testing.T) {
 					Homepage:    "https://goreleaser.com",
 					Goamd64:     "v1",
 					Install:     `bin.install "foo"`,
-					Tap: config.RepoRef{
+					Repository: config.RepoRef{
 						Owner: "foo",
 						Name:  "bar",
 					},
@@ -451,7 +455,7 @@ func TestRunPipeNameTemplate(t *testing.T) {
 	require.NoError(t, err)
 	require.NoError(t, f.Close())
 	client := client.NewMock()
-	distFile := filepath.Join(folder, "foo_is_bar.rb")
+	distFile := filepath.Join(folder, "homebrew", "foo_is_bar.rb")
 
 	require.NoError(t, runAll(ctx, client))
 	require.NoError(t, publishAll(ctx, client))
@@ -472,7 +476,7 @@ func TestRunPipeMultipleBrewsWithSkip(t *testing.T) {
 				{
 					Name:    "foo",
 					Goamd64: "v1",
-					Tap: config.RepoRef{
+					Repository: config.RepoRef{
 						Owner: "foo",
 						Name:  "bar",
 					},
@@ -484,7 +488,7 @@ func TestRunPipeMultipleBrewsWithSkip(t *testing.T) {
 				{
 					Name:    "bar",
 					Goamd64: "v1",
-					Tap: config.RepoRef{
+					Repository: config.RepoRef{
 						Owner: "foo",
 						Name:  "bar",
 					},
@@ -495,7 +499,7 @@ func TestRunPipeMultipleBrewsWithSkip(t *testing.T) {
 				{
 					Name:    "foobar",
 					Goamd64: "v1",
-					Tap: config.RepoRef{
+					Repository: config.RepoRef{
 						Owner: "foo",
 						Name:  "bar",
 					},
@@ -507,7 +511,7 @@ func TestRunPipeMultipleBrewsWithSkip(t *testing.T) {
 				{
 					Name:    "baz",
 					Goamd64: "v1",
-					Tap: config.RepoRef{
+					Repository: config.RepoRef{
 						Owner: "foo",
 						Name:  "bar",
 					},
@@ -549,7 +553,7 @@ func TestRunPipeMultipleBrewsWithSkip(t *testing.T) {
 	require.True(t, cli.CreatedFile)
 
 	for _, brew := range ctx.Config.Brews {
-		distFile := filepath.Join(folder, brew.Name+".rb")
+		distFile := filepath.Join(folder, "homebrew", brew.Name+".rb")
 		_, err := os.Stat(distFile)
 		require.NoError(t, err, "file should exist: "+distFile)
 	}
@@ -580,7 +584,7 @@ func TestRunPipeForMultipleAmd64Versions(t *testing.T) {
 						{
 							Name:        name,
 							Description: "Run pipe test formula",
-							Tap: config.RepoRef{
+							Repository: config.RepoRef{
 								Owner: "test",
 								Name:  "test",
 							},
@@ -664,7 +668,7 @@ func TestRunPipeForMultipleAmd64Versions(t *testing.T) {
 			}
 
 			client := client.NewMock()
-			distFile := filepath.Join(folder, name+".rb")
+			distFile := filepath.Join(folder, "homebrew", name+".rb")
 
 			require.NoError(t, runAll(ctx, client))
 			require.NoError(t, publishAll(ctx, client))
@@ -706,7 +710,7 @@ func TestRunPipeForMultipleArmVersions(t *testing.T) {
 							Dependencies: []config.HomebrewDependency{{Name: "zsh"}, {Name: "bash", Type: "recommended"}},
 							Conflicts:    []string{"gtk+", "qt"},
 							Install:      `bin.install "{{ .ProjectName }}"`,
-							Tap: config.RepoRef{
+							Repository: config.RepoRef{
 								Owner: "test",
 								Name:  "test",
 							},
@@ -783,7 +787,7 @@ func TestRunPipeForMultipleArmVersions(t *testing.T) {
 			}
 
 			client := client.NewMock()
-			distFile := filepath.Join(folder, name+".rb")
+			distFile := filepath.Join(folder, "homebrew", name+".rb")
 
 			require.NoError(t, runAll(ctx, client))
 			require.NoError(t, publishAll(ctx, client))
@@ -801,7 +805,7 @@ func TestRunPipeNoBuilds(t *testing.T) {
 	ctx := testctx.NewWithCfg(config.Project{
 		Brews: []config.Homebrew{
 			{
-				Tap: config.RepoRef{
+				Repository: config.RepoRef{
 					Owner: "test",
 					Name:  "test",
 				},
@@ -823,7 +827,7 @@ func TestRunPipeMultipleArchivesSameOsBuild(t *testing.T) {
 	ctx := testctx.NewWithCfg(config.Project{
 		Brews: []config.Homebrew{
 			{
-				Tap: config.RepoRef{
+				Repository: config.RepoRef{
 					Owner: "test",
 					Name:  "test",
 				},
@@ -974,7 +978,7 @@ func TestRunPipeBinaryRelease(t *testing.T) {
 					Name:        "foo",
 					Homepage:    "https://goreleaser.com",
 					Description: "Fake desc",
-					Tap: config.RepoRef{
+					Repository: config.RepoRef{
 						Owner: "foo",
 						Name:  "bar",
 					},
@@ -1021,7 +1025,7 @@ func TestRunPipePullRequest(t *testing.T) {
 					Name:        "foo",
 					Homepage:    "https://goreleaser.com",
 					Description: "Fake desc",
-					Tap: config.RepoRef{
+					Repository: config.RepoRef{
 						Owner:  "foo",
 						Name:   "bar",
 						Branch: "update-{{.Version}}",
@@ -1070,7 +1074,7 @@ func TestRunPipeNoUpload(t *testing.T) {
 		Release:     config.Release{},
 		Brews: []config.Homebrew{
 			{
-				Tap: config.RepoRef{
+				Repository: config.RepoRef{
 					Owner: "test",
 					Name:  "test",
 				},
@@ -1128,7 +1132,7 @@ func TestRunEmptyTokenType(t *testing.T) {
 		Release:     config.Release{},
 		Brews: []config.Homebrew{
 			{
-				Tap: config.RepoRef{
+				Repository: config.RepoRef{
 					Owner: "test",
 					Name:  "test",
 				},
@@ -1158,10 +1162,33 @@ func TestRunEmptyTokenType(t *testing.T) {
 
 func TestDefault(t *testing.T) {
 	testlib.Mktmp(t)
+	repo := config.RepoRef{
+		Owner:  "owner",
+		Name:   "name",
+		Token:  "aaa",
+		Branch: "feat",
+		Git: config.GitRepoRef{
+			URL:        "git@github.com:foo/bar",
+			SSHCommand: "ssh ",
+			PrivateKey: "/fake",
+		},
+		PullRequest: config.PullRequest{
+			Enabled: true,
+			Base: config.PullRequestBase{
+				Owner:  "foo2",
+				Name:   "bar2",
+				Branch: "branch2",
+			},
+			Draft: true,
+		},
+	}
 	ctx := testctx.NewWithCfg(config.Project{
 		ProjectName: "myproject",
 		Brews: []config.Homebrew{
-			{},
+			{
+				Plist: "<xml>... whatever</xml>",
+				Tap:   repo,
+			},
 		},
 	}, testctx.GitHubTokenType)
 	require.NoError(t, Pipe{}.Default(ctx))
@@ -1169,6 +1196,8 @@ func TestDefault(t *testing.T) {
 	require.NotEmpty(t, ctx.Config.Brews[0].CommitAuthor.Name)
 	require.NotEmpty(t, ctx.Config.Brews[0].CommitAuthor.Email)
 	require.NotEmpty(t, ctx.Config.Brews[0].CommitMessageTemplate)
+	require.Equal(t, repo, ctx.Config.Brews[0].Repository)
+	require.True(t, ctx.Deprecated)
 }
 
 func TestGHFolder(t *testing.T) {
@@ -1280,7 +1309,7 @@ func TestRunPipeUniversalBinary(t *testing.T) {
 					Name:        "unibin",
 					Homepage:    "https://goreleaser.com",
 					Description: "Fake desc",
-					Tap: config.RepoRef{
+					Repository: config.RepoRef{
 						Owner: "unibin",
 						Name:  "bar",
 					},
@@ -1313,7 +1342,7 @@ func TestRunPipeUniversalBinary(t *testing.T) {
 	require.NoError(t, err)
 	require.NoError(t, f.Close())
 	client := client.NewMock()
-	distFile := filepath.Join(folder, "unibin.rb")
+	distFile := filepath.Join(folder, "homebrew", "unibin.rb")
 
 	require.NoError(t, runAll(ctx, client))
 	require.NoError(t, publishAll(ctx, client))
@@ -1335,7 +1364,7 @@ func TestRunPipeUniversalBinaryNotReplacing(t *testing.T) {
 					Name:        "unibin",
 					Homepage:    "https://goreleaser.com",
 					Description: "Fake desc",
-					Tap: config.RepoRef{
+					Repository: config.RepoRef{
 						Owner: "unibin",
 						Name:  "bar",
 					},
@@ -1396,7 +1425,7 @@ func TestRunPipeUniversalBinaryNotReplacing(t *testing.T) {
 	require.NoError(t, err)
 	require.NoError(t, f.Close())
 	client := client.NewMock()
-	distFile := filepath.Join(folder, "unibin.rb")
+	distFile := filepath.Join(folder, "homebrew", "unibin.rb")
 
 	require.NoError(t, runAll(ctx, client))
 	require.NoError(t, publishAll(ctx, client))
