@@ -11,6 +11,7 @@ import (
 	_ "github.com/distribution/distribution/v3/registry/storage/driver/inmemory"
 	"github.com/google/go-containerregistry/pkg/name"
 	"github.com/google/go-containerregistry/pkg/v1/remote"
+	"github.com/goreleaser/goreleaser/internal/artifact"
 	"github.com/goreleaser/goreleaser/internal/testctx"
 	"github.com/goreleaser/goreleaser/internal/testlib"
 	"github.com/goreleaser/goreleaser/pkg/config"
@@ -131,6 +132,7 @@ func TestPublishPipeSuccess(t *testing.T) {
 		Labels             map[string]string
 		ExpectedLabels     map[string]string
 		Platforms          []string
+		Tags               []string
 		CreationTime       string
 		KoDataCreationTime string
 	}{
@@ -172,12 +174,30 @@ func TestPublishPipeSuccess(t *testing.T) {
 			Name:               "kodata-creation-time",
 			KoDataCreationTime: "1672531200",
 		},
+		{
+			Name: "tag-templates",
+			Tags: []string{
+				"{{if not .Prerelease }}{{.Version}}{{ end }}",
+				"   ", // empty
+			},
+		},
+		{
+			Name: "tag-template-eval-empty",
+			Tags: []string{
+				"{{.Version}}",
+				"{{if .Prerelease }}latest{{ end }}",
+			},
+		},
 	}
 
 	repository := fmt.Sprintf("%sgoreleasertest/testapp", registry)
 
 	for _, table := range table {
+		table := table
 		t.Run(table.Name, func(t *testing.T) {
+			if len(table.Tags) == 0 {
+				table.Tags = []string{table.Name}
+			}
 			ctx := testctx.NewWithCfg(config.Project{
 				ProjectName: "test",
 				Builds: []config.Build{
@@ -199,20 +219,40 @@ func TestPublishPipeSuccess(t *testing.T) {
 						Repository:         repository,
 						Labels:             table.Labels,
 						Platforms:          table.Platforms,
-						Tags:               []string{table.Name},
+						Tags:               table.Tags,
 						CreationTime:       table.CreationTime,
 						KoDataCreationTime: table.KoDataCreationTime,
 						SBOM:               table.SBOM,
 						Bare:               true,
 					},
 				},
-			})
+			}, testctx.WithVersion("1.2.0"))
 
 			require.NoError(t, Pipe{}.Default(ctx))
 			require.NoError(t, Pipe{}.Publish(ctx))
 
+			manifests := ctx.Artifacts.Filter(artifact.ByType(artifact.DockerManifest)).List()
+			require.Len(t, manifests, 1)
+			require.NotEmpty(t, manifests[0].Name)
+			require.Equal(t, manifests[0].Name, manifests[0].Path)
+			require.NotEmpty(t, manifests[0].Extra[artifact.ExtraDigest])
+			require.Equal(t, "default", manifests[0].Extra[artifact.ExtraID])
+
+			tags, err := applyTemplate(ctx, table.Tags)
+			require.NoError(t, err)
+			tags = removeEmpty(tags)
+			require.Len(t, tags, 1)
+
 			ref, err := name.ParseReference(
-				fmt.Sprintf("%s:%s", repository, table.Name),
+				fmt.Sprintf("%s:latest", repository),
+				name.Insecure,
+			)
+			require.NoError(t, err)
+			_, err = remote.Index(ref)
+			require.Error(t, err) // latest should not exist
+
+			ref, err = name.ParseReference(
+				fmt.Sprintf("%s:%s", repository, tags[0]),
 				name.Insecure,
 			)
 			require.NoError(t, err)
@@ -325,7 +365,7 @@ func TestPublishPipeError(t *testing.T) {
 		ctx := makeCtx()
 		ctx.Config.Kos[0].BaseImage = "not a valid image hopefully"
 		require.NoError(t, Pipe{}.Default(ctx))
-		require.EqualError(t, Pipe{}.Publish(ctx), `build: could not parse reference: not a valid image hopefully`)
+		require.EqualError(t, Pipe{}.Publish(ctx), `build: fetching base image: could not parse reference: not a valid image hopefully`)
 	})
 
 	t.Run("invalid label tmpl", func(t *testing.T) {
@@ -346,7 +386,7 @@ func TestPublishPipeError(t *testing.T) {
 		ctx := makeCtx()
 		ctx.Config.Kos[0].WorkingDir = t.TempDir()
 		require.NoError(t, Pipe{}.Default(ctx))
-		require.EqualError(t, Pipe{}.Publish(ctx), `build: exit status 1`)
+		require.EqualError(t, Pipe{}.Publish(ctx), `build: build: go build: exit status 1`)
 	})
 
 	t.Run("invalid tags tmpl", func(t *testing.T) {
@@ -414,7 +454,7 @@ func TestPublishPipeError(t *testing.T) {
 		require.NoError(t, Pipe{}.Default(ctx))
 		err := Pipe{}.Publish(ctx)
 		require.Error(t, err)
-		require.Contains(t, err.Error(), `publish: writing sbom: Get "https://fakerepo:8080/v2/": dial tcp:`)
+		require.Contains(t, err.Error(), `publish: Get "https://fakerepo:8080/v2/": dial tcp:`)
 	})
 }
 
