@@ -33,42 +33,6 @@ func TestRunPipeNoFormats(t *testing.T) {
 	testlib.AssertSkipped(t, Pipe{}.Run(ctx))
 }
 
-func TestDefaultsDeprecated(t *testing.T) {
-	t.Run("replacements", func(t *testing.T) {
-		ctx := testctx.NewWithCfg(config.Project{
-			NFPMs: []config.NFPM{
-				{
-					NFPMOverridables: config.NFPMOverridables{
-						Replacements: map[string]string{
-							"linux": "Tux",
-						},
-					},
-				},
-			},
-		})
-		require.NoError(t, Pipe{}.Default(ctx))
-		require.True(t, ctx.Deprecated)
-	})
-
-	t.Run("replacements overrides", func(t *testing.T) {
-		ctx := testctx.NewWithCfg(config.Project{
-			NFPMs: []config.NFPM{
-				{
-					Overrides: map[string]config.NFPMOverridables{
-						"apk": {
-							Replacements: map[string]string{
-								"linux": "Tux",
-							},
-						},
-					},
-				},
-			},
-		})
-		require.NoError(t, Pipe{}.Default(ctx))
-		require.True(t, ctx.Deprecated)
-	})
-}
-
 func TestRunPipeError(t *testing.T) {
 	ctx := testctx.NewWithCfg(config.Project{
 		Dist: t.TempDir(),
@@ -206,9 +170,6 @@ func TestRunPipe(t *testing.T) {
 							Destination: "/etc/folder",
 						},
 					},
-					Replacements: map[string]string{
-						"linux": "Tux",
-					},
 				},
 			},
 		},
@@ -304,7 +265,7 @@ func TestRunPipe(t *testing.T) {
 		}
 
 		if pkg.Goos == "linux" {
-			require.Equal(t, "foo_1.0.0_Tux_"+arch+"-10-20"+ext, pkg.Name)
+			require.Equal(t, "foo_1.0.0_linux_"+arch+"-10-20"+ext, pkg.Name)
 		} else {
 			require.Equal(t, "foo_1.0.0_ios_arm64-10-20"+ext, pkg.Name)
 		}
@@ -454,8 +415,8 @@ func doTestRunPipeConventionalNameTemplate(t *testing.T, snapshot bool) {
 			prefix + "-1.0.0.armv6hl.rpm",
 			prefix + "-1.0.0.armv7hl.rpm",
 			prefix + "-1.0.0.i386.rpm",
-			prefix + "-1.0.0.mipshardfloat.rpm",
-			prefix + "-1.0.0.mipssoftfloat.rpm",
+			prefix + "-1.0.0.mips.rpm",
+			prefix + "-1.0.0.mips.rpm",
 			prefix + "-1.0.0.x86_64.rpm",
 			prefix + "-1.0.0.x86_64v2.rpm",
 			prefix + "-1.0.0.x86_64v3.rpm",
@@ -470,10 +431,10 @@ func doTestRunPipeConventionalNameTemplate(t *testing.T, snapshot bool) {
 			prefix + "_1.0.0_armhf.deb",
 			prefix + "_1.0.0_armv7.apk",
 			prefix + "_1.0.0_i386.deb",
-			prefix + "_1.0.0_mipshardfloat.apk",
-			prefix + "_1.0.0_mipshardfloat.deb",
-			prefix + "_1.0.0_mipssoftfloat.apk",
-			prefix + "_1.0.0_mipssoftfloat.deb",
+			prefix + "_1.0.0_mips.apk",
+			prefix + "_1.0.0_mips.deb",
+			prefix + "_1.0.0_mips.apk",
+			prefix + "_1.0.0_mips.deb",
 			prefix + "_1.0.0_x86.apk",
 			prefix + "_1.0.0_x86_64.apk",
 			prefix + "_1.0.0_x86_64v2.apk",
@@ -487,8 +448,8 @@ func doTestRunPipeConventionalNameTemplate(t *testing.T, snapshot bool) {
 			prefix + "-1.0.0-1-x86_64v2.pkg.tar.zst",
 			prefix + "-1.0.0-1-x86_64v3.pkg.tar.zst",
 			prefix + "-1.0.0-1-x86_64v4.pkg.tar.zst",
-			prefix + "-1.0.0-1-mipssoftfloat.pkg.tar.zst",
-			prefix + "-1.0.0-1-mipshardfloat.pkg.tar.zst",
+			prefix + "-1.0.0-1-mips.pkg.tar.zst",
+			prefix + "-1.0.0-1-mips.pkg.tar.zst",
 		}, pkg.Name, "package name is not expected")
 		require.Equal(t, "someid", pkg.ID())
 		require.ElementsMatch(t, []string{binPath}, sources(artifact.ExtraOr(*pkg, extraFiles, files.Contents{})))
@@ -860,20 +821,50 @@ func TestDebSpecificConfig(t *testing.T) {
 
 	t.Run("lintian", func(t *testing.T) {
 		ctx := setupContext(t)
+		ctx.Parallelism = 100
 		ctx.Env = map[string]string{
 			"NFPM_SOMEID_DEB_PASSPHRASE": "hunter2",
 		}
-		ctx.Config.NFPMs[0].NFPMOverridables.Deb.Lintian = []string{
+		ctx.Config.NFPMs[0].Deb.Lintian = []string{
 			"statically-linked-binary",
 			"changelog-file-missing-in-native-package",
 		}
-		require.NoError(t, Pipe{}.Run(ctx))
+		ctx.Config.NFPMs[0].Formats = []string{"apk", "rpm", "deb", "termux.deb"}
 
+		require.NoError(t, Pipe{}.Run(ctx))
+		for _, format := range []string{"apk", "rpm"} {
+			require.NoDirExists(t, filepath.Join(ctx.Config.Dist, format))
+		}
+		require.DirExists(t, filepath.Join(ctx.Config.Dist, "deb"))
 		for _, goarch := range []string{"amd64", "386"} {
-			bts, err := os.ReadFile(filepath.Join(ctx.Config.Dist, "deb/foo_"+goarch+"/.lintian"))
+			bts, err := os.ReadFile(filepath.Join(ctx.Config.Dist, "deb", "foo_"+goarch, "lintian"))
 			require.NoError(t, err)
 			require.Equal(t, "foo: statically-linked-binary\nfoo: changelog-file-missing-in-native-package", string(bts))
 		}
+		require.DirExists(t, filepath.Join(ctx.Config.Dist, "termux.deb"))
+		for _, goarch := range []string{"x86_64", "i686"} {
+			bts, err := os.ReadFile(filepath.Join(ctx.Config.Dist, "termux.deb", "foo_"+goarch, "lintian"))
+			require.NoError(t, err)
+			require.Equal(t, "foo: statically-linked-binary\nfoo: changelog-file-missing-in-native-package", string(bts))
+		}
+	})
+
+	t.Run("lintian no debs", func(t *testing.T) {
+		ctx := setupContext(t)
+		ctx.Parallelism = 100
+		ctx.Env = map[string]string{
+			"NFPM_SOMEID_DEB_PASSPHRASE": "hunter2",
+		}
+		ctx.Config.NFPMs[0].Deb.Lintian = []string{
+			"statically-linked-binary",
+			"changelog-file-missing-in-native-package",
+		}
+		ctx.Config.NFPMs[0].Formats = []string{"apk", "rpm"}
+
+		require.NoError(t, Pipe{}.Run(ctx))
+		for _, format := range []string{"deb", "termux.deb"} {
+			require.NoDirExists(t, filepath.Join(ctx.Config.Dist, format))
+		}
 	})
 }
 
@@ -1226,9 +1217,6 @@ func TestMeta(t *testing.T) {
 							Type:        "dir",
 						},
 					},
-					Replacements: map[string]string{
-						"linux": "Tux",
-					},
 				},
 			},
 		},
@@ -1253,7 +1241,7 @@ func TestMeta(t *testing.T) {
 	for _, pkg := range packages {
 		format := pkg.Format()
 		require.NotEmpty(t, format)
-		require.Equal(t, pkg.Name, "foo_1.0.0_Tux_"+pkg.Goarch+"-10-20."+format)
+		require.Equal(t, pkg.Name, "foo_1.0.0_linux_"+pkg.Goarch+"-10-20."+format)
 		require.Equal(t, pkg.ID(), "someid")
 		require.ElementsMatch(t, []string{
 			"/var/log/foobar",
