@@ -16,6 +16,10 @@ import (
 	"github.com/stretchr/testify/require"
 )
 
+func TestContinueOnError(t *testing.T) {
+	require.True(t, Pipe{}.ContinueOnError())
+}
+
 func TestDescription(t *testing.T) {
 	require.NotEmpty(t, Pipe{}.String())
 }
@@ -28,7 +32,7 @@ func TestDefault(t *testing.T) {
 			ProjectName: "barr",
 			Scoops: []config.Scoop{
 				{
-					Bucket: config.RepoRef{
+					Repository: config.RepoRef{
 						Name: "foo",
 					},
 				},
@@ -64,6 +68,8 @@ func TestDefaultDeprecated(t *testing.T) {
 	require.NotEmpty(t, ctx.Config.Scoops[0].CommitAuthor.Name)
 	require.NotEmpty(t, ctx.Config.Scoops[0].CommitAuthor.Email)
 	require.NotEmpty(t, ctx.Config.Scoops[0].CommitMessageTemplate)
+	require.Equal(t, "foo", ctx.Config.Scoops[0].Repository.Name)
+	require.True(t, ctx.Deprecated)
 }
 
 func Test_doRun(t *testing.T) {
@@ -109,7 +115,7 @@ func Test_doRun(t *testing.T) {
 						Dist:        t.TempDir(),
 						ProjectName: "multi-arts",
 						Scoops: []config.Scoop{{
-							Bucket: config.RepoRef{
+							Repository: config.RepoRef{
 								Owner: "test",
 								Name:  "test",
 							},
@@ -149,7 +155,7 @@ func Test_doRun(t *testing.T) {
 						Dist:        t.TempDir(),
 						ProjectName: "multi-bins",
 						Scoops: []config.Scoop{{
-							Bucket: config.RepoRef{
+							Repository: config.RepoRef{
 								Owner: "test",
 								Name:  "test",
 							},
@@ -191,7 +197,7 @@ func Test_doRun(t *testing.T) {
 						Dist:        t.TempDir(),
 						ProjectName: "run-pipe",
 						Scoop: config.Scoop{
-							Bucket: config.RepoRef{
+							Repository: config.RepoRef{
 								Owner: "test",
 								Name:  "test",
 							},
@@ -226,7 +232,7 @@ func Test_doRun(t *testing.T) {
 						ProjectName: "git-run-pipe",
 						Dist:        t.TempDir(),
 						Scoop: config.Scoop{
-							Bucket: config.RepoRef{
+							Repository: config.RepoRef{
 								Name:   "test",
 								Branch: "main",
 								Git: config.GitRepoRef{
@@ -255,7 +261,7 @@ func Test_doRun(t *testing.T) {
 				tb.Helper()
 				content := testlib.CatFileFromBareRepository(
 					tb,
-					a.ctx.Config.Scoop.Bucket.Git.URL,
+					a.ctx.Config.Scoop.Repository.Git.URL,
 					"scoops/git-run-pipe.json",
 				)
 				golden.RequireEqualJSON(tb, content)
@@ -268,7 +274,7 @@ func Test_doRun(t *testing.T) {
 					config.Project{
 						ProjectName: "run-pipe",
 						Scoop: config.Scoop{
-							Bucket: config.RepoRef{
+							Repository: config.RepoRef{
 								Owner: "test",
 								Name:  "test",
 							},
@@ -315,7 +321,7 @@ func Test_doRun(t *testing.T) {
 						GitHubURLs:  config.GitHubURLs{Download: "https://api.custom.github.enterprise.com"},
 						ProjectName: "run-pipe",
 						Scoop: config.Scoop{
-							Bucket: config.RepoRef{
+							Repository: config.RepoRef{
 								Owner: "test",
 								Name:  "test",
 							},
@@ -347,7 +353,7 @@ func Test_doRun(t *testing.T) {
 					config.Project{
 						ProjectName: "run-pipe",
 						Scoop: config.Scoop{
-							Bucket: config.RepoRef{
+							Repository: config.RepoRef{
 								Owner: "test",
 								Name:  "test",
 							},
@@ -388,7 +394,7 @@ func Test_doRun(t *testing.T) {
 						GitHubURLs:  config.GitHubURLs{Download: "https://api.custom.gitlab.enterprise.com"},
 						ProjectName: "run-pipe",
 						Scoop: config.Scoop{
-							Bucket: config.RepoRef{
+							Repository: config.RepoRef{
 								Owner: "test",
 								Name:  "test",
 							},
@@ -428,7 +434,7 @@ func Test_doRun(t *testing.T) {
 					config.Project{
 						ProjectName: "run-pipe",
 						Scoop: config.Scoop{
-							Bucket: config.RepoRef{
+							Repository: config.RepoRef{
 								Owner: "test",
 								Name:  "test",
 							},
@@ -455,7 +461,7 @@ func Test_doRun(t *testing.T) {
 						ProjectName: "run-pipe",
 						Scoop: config.Scoop{
 							SkipUpload: "auto",
-							Bucket: config.RepoRef{
+							Repository: config.RepoRef{
 								Owner: "test",
 								Name:  "test",
 							},
@@ -486,7 +492,7 @@ func Test_doRun(t *testing.T) {
 						ProjectName: "run-pipe",
 						Scoop: config.Scoop{
 							SkipUpload: "true",
-							Bucket: config.RepoRef{
+							Repository: config.RepoRef{
 								Owner: "test",
 								Name:  "test",
 							},
@@ -508,38 +514,6 @@ func Test_doRun(t *testing.T) {
 			shouldErr("scoop.skip_upload is true"),
 			noAssertions,
 		},
-		{
-			"release is disabled",
-			args{
-				testctx.NewWithCfg(
-					config.Project{
-						ProjectName: "run-pipe",
-						Release: config.Release{
-							Disable: "true",
-						},
-						Scoop: config.Scoop{
-							Bucket: config.RepoRef{
-								Owner: "test",
-								Name:  "test",
-							},
-							Description: "A run pipe test formula",
-							Homepage:    "https://github.com/goreleaser",
-						},
-					},
-					testctx.GitHubTokenType,
-					testctx.WithCurrentTag("v1.0.1"),
-					testctx.WithVersion("1.0.1"),
-				),
-				client.NewMock(),
-			},
-			[]artifact.Artifact{
-				{Name: "foo_1.0.1_windows_amd64.tar.gz", Goos: "windows", Goarch: "amd64", Goamd64: "v1", Path: file},
-				{Name: "foo_1.0.1_windows_386.tar.gz", Goos: "windows", Goarch: "386", Path: file},
-			},
-			shouldNotErr,
-			shouldErr("release is disabled"),
-			noAssertions,
-		},
 		{
 			"no archive",
 			args{
@@ -547,7 +521,7 @@ func Test_doRun(t *testing.T) {
 					config.Project{
 						ProjectName: "run-pipe",
 						Scoop: config.Scoop{
-							Bucket: config.RepoRef{
+							Repository: config.RepoRef{
 								Owner: "test",
 								Name:  "test",
 							},
@@ -566,6 +540,114 @@ func Test_doRun(t *testing.T) {
 			shouldNotErr,
 			noAssertions,
 		},
+		{
+			"invalid name tmpl",
+			args{
+				testctx.NewWithCfg(
+					config.Project{
+						ProjectName: "run-pipe",
+						Scoop: config.Scoop{
+							Repository: config.RepoRef{
+								Owner: "test",
+								Name:  "test",
+							},
+							Name: "{{.Nope}}",
+						},
+					},
+					testctx.GitHubTokenType,
+					testctx.WithCurrentTag("v1.0.1"),
+					testctx.WithVersion("1.0.1"),
+				),
+				client.NewMock(),
+			},
+			[]artifact.Artifact{
+				{Name: "foo_1.0.1-pre.1_windows_amd64.tar.gz", Goos: "windows", Goarch: "amd64", Goamd64: "v1", Path: file},
+			},
+			testlib.RequireTemplateError,
+			shouldNotErr,
+			noAssertions,
+		},
+		{
+			"invalid description tmpl",
+			args{
+				testctx.NewWithCfg(
+					config.Project{
+						ProjectName: "run-pipe",
+						Scoop: config.Scoop{
+							Repository: config.RepoRef{
+								Owner: "test",
+								Name:  "test",
+							},
+							Description: "{{.Nope}}",
+						},
+					},
+					testctx.GitHubTokenType,
+					testctx.WithCurrentTag("v1.0.1"),
+					testctx.WithVersion("1.0.1"),
+				),
+				client.NewMock(),
+			},
+			[]artifact.Artifact{
+				{Name: "foo_1.0.1-pre.1_windows_amd64.tar.gz", Goos: "windows", Goarch: "amd64", Goamd64: "v1", Path: file},
+			},
+			testlib.RequireTemplateError,
+			shouldNotErr,
+			noAssertions,
+		},
+		{
+			"invalid homepage tmpl",
+			args{
+				testctx.NewWithCfg(
+					config.Project{
+						ProjectName: "run-pipe",
+						Scoop: config.Scoop{
+							Repository: config.RepoRef{
+								Owner: "test",
+								Name:  "test",
+							},
+							Homepage: "{{.Nope}}",
+						},
+					},
+					testctx.GitHubTokenType,
+					testctx.WithCurrentTag("v1.0.1"),
+					testctx.WithVersion("1.0.1"),
+				),
+				client.NewMock(),
+			},
+			[]artifact.Artifact{
+				{Name: "foo_1.0.1-pre.1_windows_amd64.tar.gz", Goos: "windows", Goarch: "amd64", Goamd64: "v1", Path: file},
+			},
+			testlib.RequireTemplateError,
+			shouldNotErr,
+			noAssertions,
+		},
+		{
+			"invalid skip upload tmpl",
+			args{
+				testctx.NewWithCfg(
+					config.Project{
+						ProjectName: "run-pipe",
+						Scoop: config.Scoop{
+							Repository: config.RepoRef{
+								Owner: "test",
+								Name:  "test",
+							},
+							SkipUpload: "{{.Nope}}",
+						},
+					},
+					testctx.GitHubTokenType,
+					testctx.WithCurrentTag("v1.0.1"),
+					testctx.WithVersion("1.0.1"),
+				),
+				client.NewMock(),
+			},
+			[]artifact.Artifact{
+				{Name: "foo_1.0.1-pre.1_windows_amd64.tar.gz", Goos: "windows", Goarch: "amd64", Goamd64: "v1", Path: file},
+			},
+			testlib.RequireTemplateError,
+			shouldNotErr,
+			noAssertions,
+		},
 		{
 			"invalid ref tmpl",
 			args{
@@ -573,7 +655,7 @@ func Test_doRun(t *testing.T) {
 					config.Project{
 						ProjectName: "run-pipe",
 						Scoop: config.Scoop{
-							Bucket: config.RepoRef{
+							Repository: config.RepoRef{
 								Owner: "{{ .Env.aaaaaa }}",
 								Name:  "test",
 							},
@@ -591,8 +673,8 @@ func Test_doRun(t *testing.T) {
 			[]artifact.Artifact{
 				{Name: "foo_1.0.1-pre.1_windows_amd64.tar.gz", Goos: "windows", Goarch: "amd64", Goamd64: "v1", Path: file},
 			},
-			shouldNotErr,
 			testlib.RequireTemplateError,
+			shouldNotErr,
 			noAssertions,
 		},
 		{
@@ -603,7 +685,7 @@ func Test_doRun(t *testing.T) {
 						Env:         []string{"FOO=test", "BRANCH=main"},
 						ProjectName: "run-pipe",
 						Scoops: []config.Scoop{{
-							Bucket: config.RepoRef{
+							Repository: config.RepoRef{
 								Owner:  "{{ .Env.FOO }}",
 								Name:   "{{ .Env.FOO }}",
 								Branch: "{{ .Env.BRANCH }}",
@@ -633,6 +715,7 @@ func Test_doRun(t *testing.T) {
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
 			ctx := tt.args.ctx
+			ctx.Config.Dist = t.TempDir()
 			for _, a := range tt.artifacts {
 				a := a
 				a.Type = artifact.UploadableArchive
@@ -655,10 +738,10 @@ func TestRunPipePullRequest(t *testing.T) {
 			Dist:        folder,
 			ProjectName: "foo",
 			Scoops: []config.Scoop{{
-				Name:        "foo",
-				Homepage:    "https://goreleaser.com",
-				Description: "Fake desc",
-				Bucket: config.RepoRef{
+				Name:        "{{.Env.FOO}}",
+				Homepage:    "https://{{.Env.FOO}}.com",
+				Description: "Fake desc for {{.ProjectName}}",
+				Repository: config.RepoRef{
 					Owner:  "foo",
 					Name:   "bar",
 					Branch: "update-{{.Version}}",
@@ -670,6 +753,7 @@ func TestRunPipePullRequest(t *testing.T) {
 		},
 		testctx.WithVersion("1.2.1"),
 		testctx.WithCurrentTag("v1.2.1"),
+		testctx.WithEnv(map[string]string{"FOO": "foobar"}),
 	)
 	path := filepath.Join(folder, "dist/foo_windows_amd64/foo.exe")
 	ctx.Artifacts.Add(&artifact.Artifact{
@@ -722,7 +806,7 @@ func Test_buildManifest(t *testing.T) {
 						},
 					},
 					Scoop: config.Scoop{
-						Bucket: config.RepoRef{
+						Repository: config.RepoRef{
 							Owner: "test",
 							Name:  "test",
 						},
@@ -751,7 +835,7 @@ func Test_buildManifest(t *testing.T) {
 						},
 					},
 					Scoop: config.Scoop{
-						Bucket: config.RepoRef{
+						Repository: config.RepoRef{
 							Owner: "test",
 							Name:  "test",
 						},
@@ -776,7 +860,7 @@ func Test_buildManifest(t *testing.T) {
 					},
 					ProjectName: "run-pipe",
 					Scoop: config.Scoop{
-						Bucket: config.RepoRef{
+						Repository: config.RepoRef{
 							Owner: "test",
 							Name:  "test",
 						},
@@ -801,7 +885,7 @@ func Test_buildManifest(t *testing.T) {
 					},
 					ProjectName: "run-pipe",
 					Scoop: config.Scoop{
-						Bucket: config.RepoRef{
+						Repository: config.RepoRef{
 							Owner: "test",
 							Name:  "test",
 						},
@@ -884,7 +968,7 @@ func getScoopPipeSkipCtx(folder string) (*context.Context, string) {
 			Dist:        folder,
 			ProjectName: "run-pipe",
 			Scoop: config.Scoop{
-				Bucket: config.RepoRef{
+				Repository: config.RepoRef{
 					Owner: "test",
 					Name:  "test",
 				},
@@ -941,7 +1025,7 @@ func TestRunPipeScoopWithSkipUpload(t *testing.T) {
 	require.NoError(t, runAll(ctx, cli))
 	require.EqualError(t, publishAll(ctx, cli), `scoop.skip_upload is true`)
 
-	distFile := filepath.Join(folder, ctx.Config.Scoop.Name+".json")
+	distFile := filepath.Join(folder, "scoop", ctx.Config.Scoop.Name+".json")
 	_, err = os.Stat(distFile)
 	require.NoError(t, err, "file should exist: "+distFile)
 }
@@ -958,7 +1042,7 @@ func TestWrapInDirectory(t *testing.T) {
 			},
 			ProjectName: "run-pipe",
 			Scoops: []config.Scoop{{
-				Bucket: config.RepoRef{
+				Repository: config.RepoRef{
 					Owner: "test",
 					Name:  "test",
 				},
@@ -1008,7 +1092,7 @@ func TestSkip(t *testing.T) {
 	t.Run("dont skip", func(t *testing.T) {
 		ctx := testctx.NewWithCfg(config.Project{
 			Scoop: config.Scoop{
-				Bucket: config.RepoRef{
+				Repository: config.RepoRef{
 					Name: "a",
 				},
 			},
