@@ -17,6 +17,10 @@ import (
 	"github.com/stretchr/testify/require"
 )
 
+func TestContinueOnError(t *testing.T) {
+	require.True(t, Pipe{}.ContinueOnError())
+}
+
 func TestDescription(t *testing.T) {
 	require.NotEmpty(t, Pipe{}.String())
 }
@@ -315,11 +319,7 @@ func TestRunPipeMetadata(t *testing.T) {
 }
 
 func TestNoSnapcraftInPath(t *testing.T) {
-	path := os.Getenv("PATH")
-	defer func() {
-		require.NoError(t, os.Setenv("PATH", path))
-	}()
-	require.NoError(t, os.Setenv("PATH", ""))
+	t.Setenv("PATH", "")
 	ctx := testctx.NewWithCfg(config.Project{
 		Snapcrafts: []config.Snapcraft{
 			{
@@ -470,8 +470,8 @@ func TestExtraFile(t *testing.T) {
 
 	apath := filepath.Join(dist, "foo_amd64", "prime", "a", "b", "c", "extra-file.txt")
 	bpath := filepath.Join(dist, "foo_amd64", "prime", "testdata", "extra-file-2.txt")
-	requireEqualFileConents(t, "testdata/extra-file.txt", apath)
-	requireEqualFileConents(t, "testdata/extra-file-2.txt", bpath)
+	requireEqualFileContents(t, "testdata/extra-file.txt", apath)
+	requireEqualFileContents(t, "testdata/extra-file-2.txt", bpath)
 }
 
 func TestDefault(t *testing.T) {
@@ -706,7 +706,7 @@ func TestDependencies(t *testing.T) {
 	require.Equal(t, []string{"snapcraft"}, Pipe{}.Dependencies(ctx))
 }
 
-func requireEqualFileConents(tb testing.TB, a, b string) {
+func requireEqualFileContents(tb testing.TB, a, b string) {
 	tb.Helper()
 	eq, err := gio.EqualFileContents(a, b)
 	require.NoError(tb, err)
