@@ -15,10 +15,9 @@ import (
 
 // Run a shell command with given arguments and envs
 func Run(ctx *context.Context, dir string, command, env []string, output bool) error {
-	fields := log.Fields{
-		"cmd": command,
-		"env": env,
-	}
+	log := log.
+		WithField("cmd", command).
+		WithField("env", env)
 
 	/* #nosec */
 	cmd := exec.CommandContext(ctx, command[0], command[1:]...)
@@ -27,16 +26,16 @@ func Run(ctx *context.Context, dir string, command, env []string, output bool) e
 	var b bytes.Buffer
 	w := gio.Safe(&b)
 
-	cmd.Stderr = io.MultiWriter(logext.NewConditionalWriter(fields, logext.Error, output), w)
-	cmd.Stdout = io.MultiWriter(logext.NewConditionalWriter(fields, logext.Info, output), w)
+	cmd.Stderr = io.MultiWriter(logext.NewConditionalWriter(output), w)
+	cmd.Stdout = io.MultiWriter(logext.NewConditionalWriter(output), w)
 
 	if dir != "" {
 		cmd.Dir = dir
 	}
 
-	log.WithFields(fields).Debug("running")
+	log.Debug("running")
 	if err := cmd.Run(); err != nil {
-		log.WithFields(fields).WithError(err).Debug("failed")
+		log.WithError(err).Debug("failed")
 		return fmt.Errorf("failed to run '%s': %w", strings.Join(command, " "), err)
 	}
 
